@@ -1,4 +1,5 @@
 import copy
+import functools
 import re
 import typing
 from collections import defaultdict
@@ -666,8 +667,13 @@ class AutoSchema(ViewInspector):
             # read_only fields do not have a Manager by design. go around and get field
             # from parent. also avoid calling Manager. __bool__ as it might be customized
             # to hit the database.
-            if getattr(field, 'queryset', None) is not None and not is_slug:
-                model_field = field.queryset.model._meta.pk
+            if getattr(field, 'queryset', None) is not None:
+                if is_slug:
+                    model = field.queryset.model
+                    source = [field.slug_field]
+                    model_field = follow_field_source(model, source, default=models.TextField())
+                else:
+                    model_field = field.queryset.model._meta.pk
             else:
                 if isinstance(field.parent, serializers.ManyRelatedField):
                     model = field.parent.parent.Meta.model
@@ -689,14 +695,19 @@ class AutoSchema(ViewInspector):
 
                 # estimates the relating model field and jumps to its target model PK field.
                 # also differentiate as source can be direct (pk) or relation field (model).
-                model_field = follow_field_source(model, source)
-                if callable(model_field):
-                    # follow_field_source bailed with a warning. be graceful and default to str.
-                    model_field = models.TextField()
+                # be graceful and default to string.
+                model_field = follow_field_source(model, source, default=models.TextField())
+
+            # Special case: SlugRelatedField also allows to point to a callable @property.
+            if callable(model_field):
+                schema = self._map_response_type_hint(model_field)
+            elif isinstance(model_field, models.Field):
+                schema = self._map_model_field(model_field, direction)
+            else:
+                assert False, f'Field "{field.field_name}" must point to either a property or a model field.'
 
             # primary keys are usually non-editable (readOnly=True) and map_model_field correctly
             # signals that attribute. however this does not apply in the context of relations.
-            schema = self._map_model_field(model_field, direction)
             schema.pop('readOnly', None)
             return append_meta(schema, meta)
 
@@ -713,7 +724,10 @@ class AutoSchema(ViewInspector):
             return append_meta(build_array_type(build_choice_field(field)), meta)
 
         if isinstance(field, serializers.ChoiceField):
-            return append_meta(build_choice_field(field), meta)
+            schema = build_choice_field(field)
+            if 'description' in meta:
+                meta['description'] = meta['description'] + '\n\n' + schema.pop('description')
+            return append_meta(schema, meta)
 
         if isinstance(field, serializers.ListField):
             if isinstance(field.child, _UnvalidatedField):
@@ -945,13 +959,24 @@ class AutoSchema(ViewInspector):
                 if not field.read_only:
                     meta['minLength'] = 1
         if field.default is not None and field.default != empty and not callable(field.default):
-            if isinstance(field, (serializers.ModelField, serializers.SerializerMethodField)):
-                # Skip coercion for lack of a better solution. ModelField.to_representation()
-                # and SerializerMethodField.to_representation() are special in that they require
+            if isinstance(
+                field,
+                (
+                    serializers.ModelField,
+                    serializers.SerializerMethodField,
+                    serializers.PrimaryKeyRelatedField,
+                    serializers.SlugRelatedField,
+                ),
+            ):
+                # Skip coercion for lack of a better solution. These are special in that they require
                 # a model instance or object (which we don't have) instead of a plain value.
                 default = field.default
             else:
-                default = field.to_representation(field.default)
+                try:
+                    # gracefully attempt to transform value or just use as plain on error
+                    default = field.to_representation(field.default)
+                except:  # noqa: E722
+                    default = field.default
             if isinstance(default, set):
                 default = list(default)
             meta['default'] = default
@@ -1028,20 +1053,24 @@ class AutoSchema(ViewInspector):
         for v in field.validators:
             if schema_type == 'string':
                 if isinstance(v, validators.EmailValidator):
-                    schema['format'] = 'email'
+                    if 'format' not in schema:
+                        schema['format'] = 'email'
                 elif isinstance(v, validators.URLValidator):
-                    schema['format'] = 'uri'
+                    if 'format' not in schema:
+                        schema['format'] = 'uri'
                 elif isinstance(v, validators.RegexValidator):
-                    pattern = v.regex.pattern.encode('ascii', 'backslashreplace').decode()
-                    pattern = pattern.replace(r'\x', r'\u00')  # unify escaping
-                    pattern = pattern.replace(r'\Z', '$').replace(r'\A', '^')  # ECMA anchors
-                    schema['pattern'] = pattern
+                    if 'pattern' not in schema:
+                        pattern = v.regex.pattern.encode('ascii', 'backslashreplace').decode()
+                        pattern = pattern.replace(r'\x', r'\u00')  # unify escaping
+                        pattern = pattern.replace(r'\Z', '$').replace(r'\A', '^')  # ECMA anchors
+                        schema['pattern'] = pattern
                 elif isinstance(v, validators.MaxLengthValidator):
                     update_constraint(schema, 'maxLength', min, v.limit_value)
                 elif isinstance(v, validators.MinLengthValidator):
                     update_constraint(schema, 'minLength', max, v.limit_value)
                 elif isinstance(v, validators.FileExtensionValidator) and v.allowed_extensions:
-                    schema['pattern'] = '(?:%s)$' % '|'.join([re.escape(extn) for extn in v.allowed_extensions])
+                    if 'pattern' not in schema:
+                        schema['pattern'] = '(?:%s)$' % '|'.join([re.escape(extn) for extn in v.allowed_extensions])
             elif schema_type in ('integer', 'number'):
                 if isinstance(v, validators.MaxValueValidator):
                     update_constraint(schema, 'maximum', min, v.limit_value)
@@ -1071,7 +1100,7 @@ class AutoSchema(ViewInspector):
             return hint
 
         try:
-            return resolve_type_hint(hint)
+            schema = resolve_type_hint(hint)
         except UnableToProceedError:
             warn(
                 f'unable to resolve type hint for function "{method.__name__}". Consider '
@@ -1079,6 +1108,14 @@ class AutoSchema(ViewInspector):
             )
             return build_basic_type(OpenApiTypes.STR)
 
+        description = get_doc(
+            method.func if isinstance(method, functools.partial) else method
+        )
+        if description:
+            schema['description'] = description
+
+        return schema
+
     def _get_paginator(self):
         pagination_class = getattr(self.view, 'pagination_class', None)
         if pagination_class:
@@ -1099,7 +1136,7 @@ class AutoSchema(ViewInspector):
 
         # Either use whitelist or default back to old behavior by excluding BrowsableAPIRenderer
         def use_renderer(r):
-            if spectacular_settings.RENDERER_WHITELIST:
+            if spectacular_settings.RENDERER_WHITELIST is not None:
                 return whitelisted(r, spectacular_settings.RENDERER_WHITELIST)
             else:
                 return not isinstance(r, renderers.BrowsableAPIRenderer)
@@ -1171,9 +1208,19 @@ class AutoSchema(ViewInspector):
                 continue
             if direction == 'response' and example.request_only:
                 continue
-            if media_type and media_type != example.media_type:
+            # default to 'application/json' unless nested in OpenApiResponse, in which case inherit
+            if not example.media_type:
+                example_media_type = media_type if (example in extras) else 'application/json'
+            else:
+                example_media_type = example.media_type
+            if media_type and media_type != example_media_type:
                 continue
-            if status_code and status_code not in example.status_codes:
+            # default to [200, 201] unless nested in OpenApiResponse, in which case inherit
+            if not example.status_codes:
+                example_status_codes = (status_code,) if (example in extras) else ('200', '201')
+            else:
+                example_status_codes = tuple(map(str, example.status_codes))
+            if status_code and status_code not in example_status_codes:
                 continue
 
             if (
