@@ -1,6 +1,6 @@
 import inspect
 import sys
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, TypeVar, Union
+from typing import Any, Callable, Dict, Optional, Sequence, Tuple, Type, TypeVar, Union
 
 # direct import due to https://github.com/microsoft/pyright/issues/3025
 if sys.version_info >= (3, 8):
@@ -64,11 +64,19 @@ class PolymorphicProxySerializer(Serializer):
     *drf-spectacular* processes the serializer. In those cases you can explicitly state
     the mapping with ``{'legal': LegalPersonSerializer, ...}``, but it is then your
     responsibility to have a valid mapping.
+
+    It is also permissible to provide a callable with no parameters for ``serializers``,
+    such as a lambda that will return an appropriate list or dict when evaluated.
     """
     def __init__(
             self,
             component_name: str,
-            serializers: Union[List[_SerializerType], Dict[str, _SerializerType]],
+            serializers: Union[
+                Sequence[_SerializerType],
+                Dict[str, _SerializerType],
+                Callable[[], Sequence[_SerializerType]],
+                Callable[[], Dict[str, _SerializerType]]
+            ],
             resource_type_field_name: Optional[str],
             many: Optional[bool] = None,
     ):
@@ -88,6 +96,16 @@ class PolymorphicProxySerializer(Serializer):
         instance._many = many
         return instance
 
+    @property
+    def serializers(self):
+        if callable(self._serializers):
+            self._serializers = self._serializers()
+        return self._serializers
+
+    @serializers.setter
+    def serializers(self, value):
+        self._serializers = value
+
     @property
     def data(self):
         self._trap()
@@ -120,6 +138,11 @@ class OpenApiExample(OpenApiSchemaBase):
     The example will be attached to the operation object where appropriate,
     i.e. where the given ``media_type``, ``status_code`` and modifiers match.
     Example that do not match any scenario are ignored.
+
+    - media_type will default to 'application/json' unless implicitly specified
+      through :class:`.OpenApiResponse`
+    - status_codes will default to [200, 201] unless implicitly specified
+      through :class:`.OpenApiResponse`
     """
     def __init__(
             self,
@@ -131,8 +154,8 @@ class OpenApiExample(OpenApiSchemaBase):
             request_only: bool = False,
             response_only: bool = False,
             parameter_only: Optional[Tuple[str, _ParameterLocationType]] = None,
-            media_type: str = 'application/json',
-            status_codes: Optional[List[Union[str, int]]] = None,
+            media_type: Optional[str] = None,
+            status_codes: Optional[Sequence[Union[str, int]]] = None,
     ):
         self.name = name
         self.summary = summary
@@ -143,7 +166,7 @@ class OpenApiExample(OpenApiSchemaBase):
         self.response_only = response_only
         self.parameter_only = parameter_only
         self.media_type = media_type
-        self.status_codes = list(map(str, status_codes)) if status_codes else ['200', '201']
+        self.status_codes = status_codes
 
 
 class OpenApiParameter(OpenApiSchemaBase):
@@ -169,7 +192,7 @@ class OpenApiParameter(OpenApiSchemaBase):
             location: _ParameterLocationType = QUERY,
             required: bool = False,
             description: str = '',
-            enum: Optional[List[Any]] = None,
+            enum: Optional[Sequence[Any]] = None,
             pattern: Optional[str] = None,
             deprecated: bool = False,
             style: Optional[str] = None,
@@ -177,10 +200,10 @@ class OpenApiParameter(OpenApiSchemaBase):
             default: Any = None,
             allow_blank: bool = True,
             many: Optional[bool] = None,
-            examples: Optional[List[OpenApiExample]] = None,
+            examples: Optional[Sequence[OpenApiExample]] = None,
             extensions: Optional[Dict[str, Any]] = None,
             exclude: bool = False,
-            response: Union[bool, List[Union[int, str]]] = False,
+            response: Union[bool, Sequence[Union[int, str]]] = False,
     ):
         self.name = name
         self.type = type
@@ -214,7 +237,7 @@ class OpenApiResponse(OpenApiSchemaBase):
             self,
             response: Any = None,
             description: str = '',
-            examples: Optional[List[OpenApiExample]] = None
+            examples: Optional[Sequence[OpenApiExample]] = None
     ):
         self.response = response
         self.description = description
@@ -256,22 +279,22 @@ class OpenApiCallback(OpenApiSchemaBase):
 
 def extend_schema(
         operation_id: Optional[str] = None,
-        parameters: Optional[List[Union[OpenApiParameter, _SerializerType]]] = None,
+        parameters: Optional[Sequence[Union[OpenApiParameter, _SerializerType]]] = None,
         request: Any = empty,
         responses: Any = empty,
-        auth: Optional[List[str]] = None,
+        auth: Optional[Sequence[str]] = None,
         description: Optional[str] = None,
         summary: Optional[str] = None,
         deprecated: Optional[bool] = None,
-        tags: Optional[List[str]] = None,
+        tags: Optional[Sequence[str]] = None,
         filters: Optional[bool] = None,
         exclude: bool = False,
         operation: Optional[Dict] = None,
-        methods: Optional[List[str]] = None,
-        versions: Optional[List[str]] = None,
-        examples: Optional[List[OpenApiExample]] = None,
+        methods: Optional[Sequence[str]] = None,
+        versions: Optional[Sequence[str]] = None,
+        examples: Optional[Sequence[OpenApiExample]] = None,
         extensions: Optional[Dict[str, Any]] = None,
-        callbacks: Optional[List[OpenApiCallback]] = None,
+        callbacks: Optional[Sequence[OpenApiCallback]] = None,
         external_docs: Optional[Union[Dict[str, str], str]] = None,
 ) -> Callable[[F], F]:
     """
@@ -505,9 +528,9 @@ def extend_schema_field(
 
 def extend_schema_serializer(
         many: Optional[bool] = None,
-        exclude_fields: Optional[List[str]] = None,
-        deprecate_fields: Optional[List[str]] = None,
-        examples: Optional[List[OpenApiExample]] = None,
+        exclude_fields: Optional[Sequence[str]] = None,
+        deprecate_fields: Optional[Sequence[str]] = None,
+        examples: Optional[Sequence[OpenApiExample]] = None,
         extensions: Optional[Dict[str, Any]] = None,
         component_name: Optional[str] = None,
 ) -> Callable[[F], F]:
